"""
Utility methods for the Spotify query API
"""
from typing import Iterable, Optional

from spotify_model import Paging, SearchAlbum
from spotipy import Spotify

from .util import exhaust


def _search_albums(client: Spotify, search_str: str) -> Paging:
    def _search(limit: int, offset: int) -> Paging:
        return Paging(**client.search(search_str, limit=limit, offset=offset, type="album")["albums"])

    return _search


def search_albums(
    client: Spotify, search_str: Optional[str] = None, artist: Optional[str] = None, label: Optional[str] = None
) -> Iterable[SearchAlbum]:
    "Display albums from a search string"

    query_items = [
        search_str,
        f'artist:"{artist}"' if artist is not None else None,
        f'label:"{label}"' if label is not None else None,
    ]
    query_str = " ".join([i for i in query_items if i is not None])

    if not query_str:
        return

    for item in exhaust(_search_albums(client, query_str)):
        yield SearchAlbum(**item)
